-- File: Functions.lua
-- What's for: We use this file for the functions of the addon.

local SAYKARMA_CURRENT_VERSION = GetAddOnMetadata("SayKarma", "Version"); -- get the version from the toc file (tag: #Version)
local SAYKARMA_DESCRIPTION = GetAddOnMetadata("SayKarma", "Notes"); -- get the description from the toc file (tag: #Notes)
local SayKarmaCommand = CreateFrame("Frame");

SayKarmaCommand:RegisterEvent("ADDON_LOADED");

-- Slash commands
SLASH_SAYKARMACMD1 = '/sk';
SLASH_SAYKARMACMD2 = '/saykarma';

-- Slash command: arguments dectection
function SlashCmdList.SAYKARMACMD(msg, editbox)
    -- Since there is a sensitive case detection, we put our slash commands and arguments to lowercase 
    if (msg ~= nil) then
        msg = string.lower(msg);
    end

    -- show the basic-commands
    if (msg == "help") then
        print("/sk help --------------------------------------------------");
        print("/sk ui: Brings up the window settings");
        print("/sk version: show the version on this addon");
        print("/sk description: show the description on this addon");
        print("/sk isEnable: check if the addon is enable or not");
        print("/sk reset yes: reset SayKarma");
        print("/sk enable/on: turn On SayKarma");
        print("/sk disable/off: turn Off SayKarma");
        print("/sk legacy: get back to the old SayKarma. Say arround you that you\'ve been touched by \"Touch of Karma\" and nothing else");
        print("/sk tab pvp/pve: set the tab key for the nearest enemy player or for the nearest enemy");
        print("/sk default: get back to the default settings");
        print("/sk list: show you some extra commands");
        print("-------------------------------------------------- /sk help");

        -- show some extra-commands

    elseif (msg == "list") then
        print("/sk list --------------------------------------------------");
        print("/sk dk/deathnight enable/disable: turn on/off Death knight detection");
        print("/sk druid/drood enable/disable: turn on/off Druid detection");
        print("/sk hunter/hunt enable/disable: turn on/off Hunt detection");
        print("/sk mage enable/disable: turn on/off mage detection");
        print("/sk monk/yoda enable/disable: turn on/off Monk detection");
        print("/sk paladin enable/disable: turn on/off Paladin detection");
        print("/sk priest enable/disable: turn on/off Priest detection");
        print("/sk rogue/rouge enable/disable: turn on/off Rogue detection");
        print("/sk shaman/sham enable/disable: turn on/off Shaman detection");
        print("/sk warlock/lock enable/disable: turn on/off Warlock detection");
        print("/sk warrior/war enable/disable: turn on/off Warrior detection");
        print("-------------------------------------------------- /sk list");

    elseif (msg == "ui") then
        InterfaceOptionsFrame_OpenToCategory(SayKarmaSettings.panel);

        -- do it a second time, since the first time it won't open the good panel (weird...)
        InterfaceOptionsFrame_OpenToCategory(SayKarmaSettings.panel);

        -- Show the version on this addon
    elseif (msg == "version") then
        print("SayKarma version: " .. SAYKARMA_CURRENT_VERSION);

        -- Show the description on this addon	
    elseif (msg == "description") then
        print("SayKarma\'s description :" .. SAYKARMA_DESCRIPTION);

        -- check if the addon is enable or not
    elseif (msg == "isEnable") or (msg == "isenable") then -- I know, isEnable is useless since I use string.lower() but I prefer to have a camel case 
        print("Is SayKarma enable ?: " .. SayKarmaPrefs['SayKarmaEnable']);

        -- enable/disable SayKarma
    elseif (msg == "enable") or (msg == "on") then
        SayKarmaFunctionEnable();
    elseif (msg == "disable") or (msg == "off") then
        SayKarmaFunctionDisable();

        -- set SayKarma to the old school version or get back the new way
    elseif (msg == "legacy") then
        SayKarmaFunctionLegacy();

        -- set SayKarma with the default settings
    elseif (msg == "default") then
        SayKarmaDefaultLoadingPrefsEnable();

        -- Reset SayKarma,
    elseif (msg == "reset yes") then
        SayKarmaResetYes();

        -- turn on/off Death knight detection	
    elseif (msg == "deathnight enable") or (msg == "dk enable") then
        SayKarmaFunctionDeathKnightEnable();
    elseif (msg == "deathnight disable") or (msg == "dk disable") then
        SayKarmaFunctionDeathKnightDisable();

        -- turn on/off Druid detection
    elseif (msg == "druid enable") or (msg == "drood enable") then
        SayKarmaFunctionDruidEnable();
    elseif (msg == "druid disable") or (msg == "drood disable") then	
        SayKarmaFunctionDruidDisable();

        -- turn on/off Hunt detection
    elseif (msg == "hunter enable") or (msg == "hunt enable") then
        SayKarmaFunctionHunterEnable();
    elseif (msg == "hunter disable") or (msg == "hunt disable") then
        SayKarmaFunctionHunterDisable();

        -- turn on/off mage detection
    elseif (msg == "mage enable") then
        SayKarmaFunctionMageEnable();
    elseif (msg == "mage disable") then
        SayKarmaFunctionMageDisable();

        -- turn on/off monk detection
    elseif (msg == "monk enable") or (msg == "yoda enable")then
        SayKarmaFunctionMonkEnable();
    elseif (msg == "monk disable") or (msg == "yoda disable") then	
        SayKarmaFunctionMonkDisable();

        -- turn on/off paladin detection
    elseif (msg == "paladin enable") then
        SayKarmaFunctionPaladinEnable();
    elseif (msg == "paladin disable") then
        SayKarmaFunctionPaladinDisable();

        -- turn on/off priest detection
    elseif (msg == "priest enable") then
        SayKarmaFunctionPriestEnable();
    elseif (msg == "priest disable") then
        SayKarmaFunctionPriestDisable();

        -- turn on/off priest detection
    elseif (msg == "rogue enable") or (msg == "rouge enable") then
        SayKarmaFunctionRogueEnable();
    elseif (msg == "rogue disable") or (msg == "rouge disable") then
        SayKarmaFunctionRogueDisable();

        -- turn on/off shaman detection
    elseif (msg == "shaman enable") or (msg == "sham enable") then
        SayKarmaFunctionShamanEnable();
    elseif (msg == "shaman disable") or (msg == "sham disable") then
        SayKarmaFunctionShamanDisable();

        -- turn on/off warlock detection
    elseif (msg == "warlock enable") or (msg == "lock enable") then
        SayKarmaFunctionWarlockEnable();
    elseif (msg == "warlock disable") or (msg == "lock disable") then
        SayKarmaFunctionWarlockDisable();

        -- turn on/off warrior detection
    elseif (msg == "warrior enable") or (msg == "war enable") then
        SayKarmaFunctionWarriorEnable();
    elseif (msg == "warrior disable") or (msg == "war disable") then
        SayKarmaFunctionWarriorDisable();

        -- use "tab" or "shift+tab" for target the nearest enemy player or the nearest ennemy
    elseif (msg == "tab pvp") then
        SayKarmaExtraSetTabPvp();
    elseif (msg == "tab pve") then
        SayKarmaExtraSetTabPve();
    else
        -- if the user use "/sk"
        print("use /sk help for more help");
    end
end

-- Enable addon, only the detection is enabled 
function SayKarmaFunctionEnable()
    SayKarmaPrefs['SayKarmaEnable'] = "yes";
    print("SayKarma enabled");
end

-- Disable addonn only the detection is disabled
function SayKarmaFunctionDisable()
    SayKarmaPrefs['SayKarmaEnable'] = "no";
    print("SayKarma disabled");
end

-- Enable DeathKnight section
function SayKarmaFunctionDeathKnightEnable()
    SayKarmaPrefs['DeathKnightEnable'] = "yes";
    print("SayKarma: DeathKnight enabled");
end

-- Disable DeathKnight section
function SayKarmaFunctionDeathKnightDisable()
    SayKarmaPrefs['DeathKnightEnable'] = "no";
    print("SayKarma: DeathKnight disabled");
end

-- Enable druid section
function SayKarmaFunctionDruidEnable()
    SayKarmaPrefs['DruidEnable'] = "yes";
    print("SayKarma: Druid enabled");
end

-- Disable druid section
function SayKarmaFunctionDruidDisable()
    SayKarmaPrefs['DruidEnable'] = "no";
    print("SayKarma: Druid disabled");
end

-- Enable hunter section
function SayKarmaFunctionHunterEnable()
    SayKarmaPrefs['HunterEnable'] = "yes";
    print("SayKarma: Hunter enabled");
end

-- Disable hunter section
function SayKarmaFunctionHunterDisable()
    SayKarmaPrefs['HunterEnable'] = "no";
    print("SayKarma: Hunter disabled");
end

-- Enable mage section
function SayKarmaFunctionMageEnable()
    SayKarmaPrefs['MageEnable'] = "yes";
    print("SayKarma: Mage enabled");
end

-- Disable mage section
function SayKarmaFunctionMageDisable()
    SayKarmaPrefs['MageEnable'] = "no";
    print("SayKarma: Mage disabled");
end

-- Enable monk section
function SayKarmaFunctionMonkEnable()
    SayKarmaPrefs['MonkEnable'] = "yes";
    print("SayKarma: Monk enabled");
end

-- Disable monk section
function SayKarmaFunctionMonkDisable()
    SayKarmaPrefs['MonkEnable'] = "no";
    print("SayKarma: Monk disabled");
end

-- Enable paladin section
function SayKarmaFunctionPaladinEnable()
    SayKarmaPrefs['PaladinEnable'] = "yes";
    print("SayKarma: Paladin enabled");
end

-- Disable paladin section
function SayKarmaFunctionPaladinDisable()
    SayKarmaPrefs['PaladinEnable'] = "no";
    print("SayKarma: Paladin disabled");
end

-- Enable priest section
function SayKarmaFunctionPriestEnable()
    SayKarmaPrefs['PriestEnable'] = "yes";
    print("SayKarma: Priest enabled");
end

-- Disable priest section
function SayKarmaFunctionPriestDisable()
    SayKarmaPrefs['PriestEnable'] = "no";
    print("SayKarma: Priest disabled");
end

-- Enable rogue section
function SayKarmaFunctionRogueEnable()
    SayKarmaPrefs['RogueEnable'] = "yes";
    print("SayKarma: Rogue enabled");
end

-- Disable rogue section
function SayKarmaFunctionRogueDisable()
    SayKarmaPrefs['RogueEnable'] = "no";
    print("SayKarma: Rogue disabled");
end

-- Enable shaman section
function SayKarmaFunctionShamanEnable()
    SayKarmaPrefs['ShamanEnable'] = "yes";
    print("SayKarma: Shaman enabled");
end

-- Disable shaman section
function SayKarmaFunctionShamanDisable()
    SayKarmaPrefs['ShamanEnable'] = "no";
    print("SayKarma: Shaman disabled");
end

-- Enable warlock section
function SayKarmaFunctionWarlockEnable()
    SayKarmaPrefs['WarlockEnable'] = "yes";
    print("SayKarma: Warlock enabled");
end

-- Disable warlock section
function SayKarmaFunctionWarlockDisable()
    SayKarmaPrefs['WarlockEnable'] = "no";
    print("SayKarma: Warlock disabled");
end

-- Enable warrior section
function SayKarmaFunctionWarriorEnable()
    SayKarmaPrefs['WarriorEnable'] = "yes";
    print("SayKarma: Warrior enabled");
end

-- Disable warrior section
function SayKarmaFunctionWarriorDisable()
    SayKarmaPrefs['WarriorEnable'] = "no";
    print("SayKarma: Warrior disabled");
end

-- Enable DeathKnight Asphyxiate;
function SayKarmaFunctionDeathKnightAsphyxiateEnable()
    SayKarmaPrefs['DeathKnightAsphyxiate'] = "yes";
    print("SayKarma: DeathKnight Asphyxiate enabled");
end

-- Disable DeathKnight Asphyxiate;
function SayKarmaFunctionDeathKnightAsphyxiateDisable()
    SayKarmaPrefs['DeathKnightAsphyxiate'] = "no";
    print("SayKarma: DeathKnight Asphyxiate disabled");
end

-- Enable DeathKnight Mind Freeze
function SayKarmaFunctionDeathKnightMindFreezeEnable()
    SayKarmaPrefs['DeathKnightMindFreeze'] = "yes";
    print("SayKarma: DeathKnight Mind Freeze enabled");
end

-- Disable DeathKnight MindFreeze
function SayKarmaFunctionDeathKnightMindFreezeDisable()
    SayKarmaPrefs['DeathKnightMindFreeze'] = "no";
    print("SayKarma: DeathKnight Mind Freeze disabled");
end

-- Enable DeathKnight Strangulate
function SayKarmaFunctionDeathKnightStrangulateEnable()
    SayKarmaPrefs['DeathKnightStrangulate'] = "yes";
    print("SayKarma: DeathKnight Strangulate enabled");
end

-- Disable DeathKnight
function SayKarmaFunctionDeathKnightStrangulateDisable()
    SayKarmaPrefs['DeathKnightStrangulate'] = "no";
    print("SayKarma: DeathKnight Strangulate disabled");
end

-- Enable Druid Fae Silence
function SayKarmaFunctionDruidFaeSilenceEnable()
    SayKarmaPrefs['DruidFaeSilence'] = "yes";
    print("SayKarma: Druid Fae Silence enabled");
end

-- Disable Druid Fae Silance
function SayKarmaFunctionDruidFaeSilenceDisable()
    SayKarmaPrefs['DruidFaeSilence'] = "no";
    print("SayKarma: Druid Fae Silence disabled");
end

-- Enable Druid Cyclone
function SayKarmaFunctionDruidCycloneEnable()
    SayKarmaPrefs['DruidCyclone'] = "yes";
    print("SayKarma: Druid Cyclone enabled");
end

-- Disable Druid Cyclone
function SayKarmaFunctionDruidCycloneDisable()
    SayKarmaPrefs['DruidCyclone'] = "no";
    print("SayKarma : Druid Cyclone disabled");
end

-- Enable Hunt Counter Shot
function SayKarmaFunctionHunterCounterShotEnable()
    SayKarmaPrefs['HunterCounterShot'] = "yes";
    print("SayKarma: Hunter Counter Shot enabled");
end

-- Disable Hunt Counter Shot
function SayKarmaFunctionHunterCounterShotDisable()
    SayKarmaPrefs['HunterCounterShot'] = "no";
    print("SayKarma: Hunter Counter Shot disabled");
end

-- Enable Hunt Freezing Trap
function SayKarmaFunctionHunterFreezingTrapEnable()
    SayKarmaPrefs['HunterFreezingTrap'] = "yes";
    print("SayKarma: Hunter Freezing Trap enabled");
end

-- Disable Hunt Freezing Trap
function SayKarmaFunctionHunterFreezingTrapDisable()
    SayKarmaPrefs['HunterFreezingTrap'] = "no";
    print("SayKarma: Hunter Freezing Trap disabled");
end

-- Enable Hunt Silencing Shot
function SayKarmaFunctionHunterSilencingShotEnable()
    SayKarmaPrefs['HunterSilencingShot'] = "yes";
    print("SayKarma: Hunter Silencing Shot enabled");
end

-- Disable Hunt Silencing Shot
function SayKarmaFunctionHunterSilencingShotDisable()
    SayKarmaPrefs['HunterSilencingShot'] = "no";
    print("SayKarma: Hunter Silencing Shot disabled");
end

-- Enable Mage Counterspell
function SayKarmaFunctionMageCounterspellEnable()
    SayKarmaPrefs['MageCounterspell'] = "yes";
    print("SayKarma: Mage Counterspell enabled");
end

-- Disable Mage Counterspell
function SayKarmaFunctionMageCounterspellDisable()
    SayKarmaPrefs['MageCounterspell'] = "no";
    print("SayKarma: Mage Counterspell disabled");
end

-- Enable Mage Deep Freeze
function SayKarmaFunctionMageDeepFreezeEnable()
    SayKarmaPrefs['MageDeepFreeze'] = "yes";
    print("SayKarma: Mage Deep Freeze enabled");
end

-- Disable Mage Deep Freeze
function SayKarmaFunctionMageDeepFreezeDisable()
    SayKarmaPrefs['MageDeepFreeze'] = "no";
    print("SayKarma: Mage Deep Freeze disabled");
end

-- Enable Mage Frostjaw
function SayKarmaFunctionMageFrostjawEnable()
    SayKarmaPrefs['MageFrostjaw'] = "yes";
    print("SayKarma: Mage Frostjaw enabled");
end

-- Disable Mage Frostjaw
function SayKarmaFunctionMageFrostjawDisable()
    SayKarmaPrefs['MageFrostjaw'] = "no";
    print("SayKarma: Mage Frostjaw disabled");
end

-- Enable Mage Polymorph
function SayKarmaFunctionMagePolymorphEnable()
    -- Keep in mind, the ui check only ['MagePolymorphSheep']
    -- we if we add a way to change only one of them, we should change the code
    -- in the Setting.lua file section: CheckButton enable Mage Polymorph
    SayKarmaPrefs['MagePolymorphBlackCat'] = "yes";
    SayKarmaPrefs['MagePolymorphMonkey'] = "yes";
    SayKarmaPrefs['MagePolymorphPeacock'] = "yes";
    SayKarmaPrefs['MagePolymorphPenguin'] = "yes";
    SayKarmaPrefs['MagePolymorphPolarBearCub'] = "yes";
    SayKarmaPrefs['MagePolymorphPig'] = "yes";
    SayKarmaPrefs['MagePolymorphRabbit'] = "yes";
    SayKarmaPrefs['MagePolymorphSheep'] = "yes";
    SayKarmaPrefs['MagePolymorphTurkey'] = "yes";
    SayKarmaPrefs['MagePolymorphTurtle'] = "yes";
    print("SayKarma: Mage Polymorph enabled");
end

-- Disable Mage Polymorph
function SayKarmaFunctionMagePolymorphDisable()
    -- Keep in mind, the ui check only ['MagePolymorphSheep']
    -- we if we add a way to change only one of them, we should change the code
    -- in the Setting.lua file section: CheckButton enable Mage Polymorph
    SayKarmaPrefs['MagePolymorphBlackCat'] = "no";
    SayKarmaPrefs['MagePolymorphMonkey'] = "no";
    SayKarmaPrefs['MagePolymorphPeacock'] = "no";
    SayKarmaPrefs['MagePolymorphPenguin'] = "no";
    SayKarmaPrefs['MagePolymorphPolarBearCub'] = "no";
    SayKarmaPrefs['MagePolymorphPig'] = "no";
    SayKarmaPrefs['MagePolymorphRabbit'] = "no";
    SayKarmaPrefs['MagePolymorphSheep'] = "no";
    SayKarmaPrefs['MagePolymorphTurkey'] = "no";
    SayKarmaPrefs['MagePolymorphTurtle'] = "no";
    print("SayKarma: Mage Polymorph disabled");
end

-- Enable Monk Leg Sweep
function SayKarmaFunctionMonkLegSweepEnable()
    SayKarmaPrefs['MonkLegSweep'] = "yes";
    print("SayKarma: Monk Leg Sweep enabled");
end

-- Disable Monk Leg Sweep
function SayKarmaFunctionMonkLegSweepDisable()
    SayKarmaPrefs['MonkLegSweep'] = "no";
    print("SayKarma: Monk Leg Sweep disabled");
end

-- Enable Monk Paralysis
function SayKarmaFunctionMonkParalysisEnable()
    SayKarmaPrefs['MonkParalysis'] = "yes";
    print("SayKarma: Monk Paralysis enabled");
end

-- Disable Monk Paralysis
function SayKarmaFunctionMonkParalysisDisable()
    SayKarmaPrefs['MonkParalysis'] = "no";
    print("SayKarma: Monk Paralysis disabled");
end

-- Enable Monk Spear Hand Strike
function SayKarmaFunctionMonkSpearHandStrikeEnable()
    SayKarmaPrefs['MonkSpearHandStrike'] = "yes";
    print("SayKarma: Monk Spear Hand Strike enabled");
end

-- Disable Monk Spear Hand Strike
function SayKarmaFunctionMonkSpearHandStrikeDisable()
    SayKarmaPrefs['MonkSpearHandStrike'] = "no";
    print("SayKarma: Monk Spear Hand Strike disabled");
end

-- Enable Monk Touch Of Karma
function SayKarmaFunctionMonkTouchOfKarmaEnable()
    SayKarmaPrefs['MonkTouchOfKarma'] = "yes";
    print("SayKarma: Monk Touch Of Karma enabled");
end

-- Disable Monk Touch Of Karma
function SayKarmaFunctionMonkTouchOfKarmaDisable()
    SayKarmaPrefs['MonkTouchOfKarma'] = "no";
    print("SayKarma: Monk Touch Of Karma disabled");
end

-- Enable Paladin Fist Of Justice
function SayKarmaFunctionPaladinFistOfJusticeEnable()
    SayKarmaPrefs['PaladinFistOfJustice'] = "yes";
    print("SayKarma: Paladin Fist Of Justice enabled");
end

-- Disable Paladin Fist Of Justice
function SayKarmaFunctionPaladinFistOfJusticeDisable()
    SayKarmaPrefs['PaladinFistOfJustice'] = "no";
    print("SayKarma: Paladin Fist Of Justice disabled");
end

-- Enable Paladin Hammer Of Justice
function SayKarmaFunctionPaladinHammerOfJusticeEnable()
    SayKarmaPrefs['PaladinHammerOfJustice'] = "yes";
    print("SayKarma: Paladin Hammer Of Justice enabled");
end

-- Disable Paladin Hammer Of Justice
function SayKarmaFunctionPaladinHammerOfJusticeDisable()
    SayKarmaPrefs['PaladinHammerOfJustice'] = "no";
    print("SayKarma: Paladin Hammer Of Justice disabled");
end

-- Enable Paladin Rebuke
function SayKarmaFunctionPaladinRebukeEnable()
    SayKarmaPrefs['PaladinRebuke'] = "yes";
    print("SayKarma: Paladin Rebuke enabled");
end

-- Disable Paladin Rebuke
function SayKarmaFunctionPaladinRebukeDisable()
    SayKarmaPrefs['PaladinRebuke'] = "no";
    print("SayKarma: Paladin Rebuke disabled");
end

-- Enable Paladin Repentance
function SayKarmaFunctionPaladinRepentanceEnable()
    SayKarmaPrefs['PaladinRepentance'] = "yes";
    print("SayKarma: Paladin Repentance enabled");
end

-- Disable Paladin Repentance
function SayKarmaFunctionPaladinRepentanceDisable()
    SayKarmaPrefs['PaladinRepentance'] = "no";
    print("SayKarma: Paladin Repentance disabled");
end

-- Enable Priest Dominate Mind
function SayKarmaFunctionPriestDominateMindEnable()
    SayKarmaPrefs['PriestDominateMind'] = "yes";
    print("SayKarma: Priest Dominate Mind enabled");
end

-- Disable Priest Dominate Mind
function SayKarmaFunctionPriestDominateMindDisable()
    SayKarmaPrefs['PriestDominateMind'] = "no";
    print("SayKarma: Priest Dominate Mind disabled");
end

-- Enable Priest Holy Word Chastise
function SayKarmaFunctionPriestHolyWordChastiseEnable()
    SayKarmaPrefs['PriestHolyWordChastise'] = "yes";
    print("SayKarma: Priest Holy Word Chastise enabled");
end

-- Disable Priest Holy Word Chastise
function SayKarmaFunctionPriestHolyWordChastiseDisable()
    SayKarmaPrefs['PriestHolyWordChastise'] = "no";
    print("SayKarma: Priest Holy Word Chastise disabled");
end

-- Enable Priest Psychic Horror
function SayKarmaFunctionPriestPsychicHorrorEnable()
    SayKarmaPrefs['PriestPsychicHorror'] = "yes";
    print("SayKarma: Priest Psychic Horror enabled");
end

-- Disable Priest Psychic Horror
function SayKarmaFunctionPriestPsychicHorrorDisable()
    SayKarmaPrefs['PriestPsychicHorror'] = "no";
    print("SayKarma: Priest Psychic Horror disabled");
end

-- Enable Priest Silence
function SayKarmaFunctionPriestSilenceEnable()
    SayKarmaPrefs['PriestSilence'] = "yes";
    print("SayKarma: Priest Silence enabled");
end

-- Disable Priest Silence
function SayKarmaFunctionPriestSilenceDisable()
    SayKarmaPrefs['PriestSilence'] = "no";
    print("SayKarma: Priest Silence disabled");
end

-- Enable Rogue Blind
function SayKarmaFunctionRogueBlindEnable()
    SayKarmaPrefs['RogueBlind'] = "yes";
    print("SayKarma: Rogue Blind enabled");
end

-- Disable Rogue Blind
function SayKarmaFunctionRogueBlindDisable()
    SayKarmaPrefs['RogueBlind'] = "no";
    print("SayKarma: Rogue Blind disabled");
end

-- Enable Rogue Garrote
function SayKarmaFunctionRogueGarroteEnable()
    SayKarmaPrefs['RogueGarrote'] = "yes";
    print("SayKarma: Rogue Garrote enabled");
end

-- Disable Rogue Garrote
function SayKarmaFunctionRogueGarroteDisable()
    SayKarmaPrefs['RogueGarrote'] = "no";
    print("SayKarma: Rogue Garrote disabled");
end

-- Enable Rogue kick
function SayKarmaFunctionRoguekickEnable()
    SayKarmaPrefs['Roguekick'] = "yes";
    print("SayKarma: Rogue kick enabled");
end

-- Disable Rogue kick
function SayKarmaFunctionRoguekickDisable()
    SayKarmaPrefs['Roguekick'] = "no";
    print("SayKarma: Rogue kick disabled");
end

-- Enable Rogue Sap
function SayKarmaFunctionRogueSapEnable()
    SayKarmaPrefs['RogueSap'] = "yes";
    print("SayKarma: Rogue Sap enabled");
end

-- Disable Rogue Sap
function SayKarmaFunctionRogueSapDisable()
    SayKarmaPrefs['RogueSap'] = "no";
    print("SayKarma: Rogue Sap disabled");
end

-- Enable Shaman Hex
function SayKarmaFunctionShamanHexEnable()
    SayKarmaPrefs['ShamanHex'] = "yes";
    print("SayKarma: Shaman Hex enabled");
end

-- Disable Shaman Hex
function SayKarmaFunctionShamanHexDisable()
    SayKarmaPrefs['ShamanHex'] = "no";
    print("SayKarma: Shaman Hex disabled");
end

-- Enable Shaman Wind Shear
function SayKarmaFunctionShamanWindShearEnable()
    SayKarmaPrefs['ShamanWindShear'] = "yes";
    print("SayKarma: Shaman Wind Shear enabled");
end

-- Disable Shaman Wind Shear
function SayKarmaFunctionShamanWindShearDisable()
    SayKarmaPrefs['ShamanWindShear'] = "no";
    print("SayKarma: Shaman Wind Shear disabled");
end

-- Enable Warlock Mesmerize
function SayKarmaFunctionWarlockMesmerizeSeductionEnable()
    SayKarmaPrefs['WarlockMesmerize'] = "yes";
    SayKarmaPrefs['WarlockSeduction'] = "yes";
    print("SayKarma: Warlock Mesmerize & Seduction enabled");
end

-- Disable Warlock Mesmerize
function SayKarmaFunctionWarlockMesmerizeSeductionDisable()
    SayKarmaPrefs['WarlockMesmerize'] = "no";
    SayKarmaPrefs['WarlockSeduction'] = "no";
    print("SayKarma: Warlock Mesmerize & Seduction disabled");
end

-- Enable Warrior Dragon Roar
function SayKarmaFunctionWarriorDragonRoarEnable()
    SayKarmaPrefs['WarriorDragonRoar'] = "yes";
    print("SayKarma: Warrior Dragon Roar enabled");
end

-- Disable Warrior Dragon Roar
function SayKarmaFunctionWarriorDragonRoarDisable()
    SayKarmaPrefs['WarriorDragonRoar'] = "no";
    print("SayKarma: Warrior Dragon Roar disabled");
end

-- Enable Warrior Pummel
function SayKarmaFunctionWarriorPummelEnable()
    SayKarmaPrefs['WarriorPummel'] = "yes";
    print("SayKarma: Warrior Pummel enabled");
end

-- Disable Warrior Pummel
function SayKarmaFunctionWarriorPummelDisable()
    SayKarmaPrefs['WarriorPummel'] = "no";
    print("SayKarma: Warrior Pummel disabled");
end

-- Enable Warrior Shockwave
function SayKarmaFunctionWarriorShockwaveEnable()
    SayKarmaPrefs['WarriorShockwave'] = "yes";
    print("SayKarma: Warrior Shockwave enabled");
end

-- Disable Warrior Shockwave
function SayKarmaFunctionWarriorShockwaveDisable()
    SayKarmaPrefs['WarriorShockwave'] = "no";
    print("SayKarma: Warrior Shockwave disabled");
end

-- Enable Warrior Storm Bolt
function SayKarmaFunctionWarriorStormBoltEnable()
    SayKarmaPrefs['WarriorStormBolt'] = "yes";
    SayKarmaPrefs['WarriorStormBoltOffHand'] = "yes";
    print("SayKarma: Warrior Storm Bolt enabled");
end

-- Disable Warrior Storm Bolt
function SayKarmaFunctionWarriorStormBoltDisable()
    SayKarmaPrefs['WarriorStormBolt'] = "no";
    SayKarmaPrefs['WarriorStormBoltOffHand'] = "no";
    print("SayKarma: Warrior Storm Bolt disabled");
end


-- Reset SayKarma, everything has to be reset
function SayKarmaResetYes()
    print("SayKarma: reset in progress");
    SAYKARMA_VERSION = nil;
    SayKarmaPrefs = nil;

    SAYKARMA_VERSION = SAYKARMA_CURRENT_VERSION;
    print("SayKarma: loading default values");
    SayKarmaDefaultLoadingPrefsEnable();
    print("SayKarma: reseted");
end

-- Set SayKarma to the old SayKarma, meaning, say arround you only if you were touched bye "Touch of Karma" and nothing else
function SayKarmaFunctionLegacy()
    -- we disable everything
    SayKarmaDefaultLoadingPrefsDisable();

    -- we enable only what we need
    SayKarmaPrefs['SayKarmaEnable'] = "yes";
    SayKarmaPrefs['DecorationEnable'] = "yes";
    SayKarmaPrefs['WhichDecoration'] = "Skull";
    SayKarmaPrefs['MonkEnable'] = "yes";
    SayKarmaPrefs['MonkTouchOfKarma'] = "yes";

    print("SayKarma \"Legacy\" mode avativated");
end

-- Loading
function SayKarmaCommand:OnEvent(event, arg1)
    -- when the addon is loaded
    if (event == "ADDON_LOADED" and arg1 == "SayKarma") then
        -- initialization
        if (SAYKARMA_VERSION == nil) then
            SAYKARMA_VERSION = SAYKARMA_CURRENT_VERSION;
        end

        if (SayKarmaPrefs == nil) then
            print("Initialization");
            SayKarmaDefaultLoadingPrefsEnable();
        end
        -- initialization over

        -- is the user had an old version ? check if we have to update some old variables
        if (SAYKARMA_VERSION ~= SAYKARMA_CURRENT_VERSION) then
            -- we clean everything
            print("Updating saved variables...");
            SayKarmaFunctionUpdateSavedVariables();
            print("Updating terminated");
        end

        -- just a simple text to make the user aware that everything is loaded and and how to use the addon
        print("SayKarma Loaded - use /sk help for more help");

    end -- ((event == "ADDON_LOADED")
end -- function SayKarmaCommand:OnEvent


-- Allow to update some saved variables Just in case
function SayKarmaFunctionUpdateSavedVariables()
    SAYKARMA_VERSION = SAYKARMA_CURRENT_VERSION;
    SayKarmaPrefs = nil;	-- reset

    -- get back with the default settings
    SayKarmaDefaultLoadingPrefsEnable();
end

-- put SayKarma with the default mode, everything is enabled
function SayKarmaDefaultLoadingPrefsEnable()
    -- let's go to enable everything
    -- I know ! I could use some booleans instead of string variables with "yes"/"no"
    -- But I don't like Booleans, besides, I do what I want 
    SayKarmaPrefs = {		-- turn on all prefs
        ['SayKarmaEnable'] = "yes",
        ['SayKarmaAutoSetTab'] = "yes",
        ['SayKarmaTabMode'] = "unknown",
        ['DecorationEnable'] = "yes",
        ['WhichDecoration'] = "Skull",
        ['DeathKnightEnable'] = "yes",
        ['DruidEnable'] = "yes",
        ['HunterEnable'] = "yes",
        ['MageEnable'] = "yes",
        ['MonkEnable'] = "yes",
        ['PaladinEnable'] = "yes",
        ['PriestEnable'] = "yes",
        ['RogueEnable'] = "yes",
        ['ShamanEnable'] = "yes",
        ['WarlockEnable'] = "yes",
        ['WarriorEnable'] = "yes",
        ['DeathKnightAsphyxiate'] = "yes",
        ['DeathKnightMindFreeze'] = "yes",
        ['DeathKnightStrangulate'] = "yes",
        ['DruidFaeSilence'] = "yes",
        ['DruidCyclone'] = "yes",
        ['HunterCounterShot'] = "yes",
        ['HunterFreezingTrap'] = "yes",
        ['HunterSilencingShot'] = "yes",
        ['MageCounterspell'] = "yes",
        ['MageDeepFreeze'] = "yes",
        ['MageFrostjaw'] = "yes",
        ['MagePolymorphBlackCat'] = "yes",
        ['MagePolymorphMonkey'] = "yes",
        ['MagePolymorphPeacock'] = "yes",
        ['MagePolymorphPenguin'] = "yes",
        ['MagePolymorphPolarBearCub'] = "yes",
        ['MagePolymorphPig'] = "yes",
        ['MagePolymorphRabbit'] = "yes",
        ['MagePolymorphSheep'] = "yes",
        ['MagePolymorphTurkey'] = "yes",
        ['MagePolymorphTurtle'] = "yes",
        ['MonkLegSweep'] = "yes",
        ['MonkParalysis'] = "yes",
        ['MonkSpearHandStrike'] = "yes",
        ['MonkTouchOfKarma'] = "yes",
        ['PaladinFistOfJustice'] = "yes",
        ['PaladinHammerOfJustice'] = "yes",
        ['PaladinRebuke'] = "yes",
        ['PaladinRepentance'] = "yes",
        ['PriestDominateMind'] = "yes",
        ['PriestHolyWordChastise'] = "yes",
        ['PriestPsychicHorror'] = "yes",
        ['PriestSilence'] = "yes",
        ['RogueBlind'] = "yes",
        ['RogueGarrote'] = "yes",
        ['Roguekick'] = "yes",
        ['RogueSap'] = "yes",
        ['ShamanHex'] = "yes",
        ['ShamanWindShear'] = "yes",
        ['WarlockMesmerize'] = "yes",
        ['WarlockSeduction'] = "yes",
        ['WarriorDragonRoar'] = 'yes',
        ['WarriorPummel'] = "yes",
        ['WarriorShockwave'] = "yes",
        ['WarriorStormBolt'] = "yes",
        ['WarriorStormBoltOffHand'] = "yes",
    };

    print("SayKarma \"Default\" mode avativated");
end

-- turn off SayKarma, everything is disabled
function SayKarmaDefaultLoadingPrefsDisable()
    -- let's go to disable everything
    SayKarmaPrefs = {			-- turn off all prefs
        ['SayKarmaEnable'] = "no",
        ['SayKarmaAutoSetTab'] = "no",
        ['SayKarmaTabMode'] = "unknown",
        ['DecorationEnable'] = "no",
        ['WhichDecoration'] = "Skull",
        ['DeathKnightEnable'] = "no",
        ['DruidEnable'] = "no",
        ['HunterEnable'] = "no",
        ['MageEnable'] = "no",
        ['MonkEnable'] = "no",
        ['PaladinEnable'] = "no",
        ['PriestEnable'] = "no",
        ['RogueEnable'] = "no",
        ['ShamanEnable'] = "no",
        ['WarlockEnable'] = "no",
        ['WarriorEnable'] = "no",
        ['DeathKnightAsphyxiate'] = "no",
        ['DeathKnightMindFreeze'] = "no",
        ['DeathKnightStrangulate'] = "no",
        ['DruidFaeSilence'] = "no",
        ['DruidCyclone'] = "no",
        ['HunterCounterShot'] = "no",
        ['HunterFreezingTrap'] = "no",
        ['HunterSilencingShot'] = "no",
        ['MageCounterspell'] = "no",
        ['MageDeepFreeze'] = "no",
        ['MageFrostjaw'] = "no",
        ['MagePolymorphBlackCat'] = "no",
        ['MagePolymorphPenguin'] = "no",
        ['MagePolymorphPolarBearCub'] = "no",
        ['MagePolymorphMonkey'] = "no",
        ['MagePolymorphPeacock'] = "no",
        ['MagePolymorphPig'] = "no",
        ['MagePolymorphRabbit'] = "no",
        ['MagePolymorphSheep'] = "no",
        ['MagePolymorphTurkey'] = "no",
        ['MagePolymorphTurtle'] = "no",
        ['MonkLegSweep'] = "no",
        ['MonkParalysis'] = "no",
        ['MonkSpearHandStrike'] = "no",
        ['MonkTouchOfKarma'] = "no",
        ['PaladinFistOfJustice'] = "no",
        ['PaladinHammerOfJustice'] = "no",
        ['PaladinRebuke'] = "no",
        ['PaladinRepentance'] = "no",
        ['PriestDominateMind'] = "no",
        ['PriestHolyWordChastise'] = "no",
        ['PriestPsychicHorror'] = "no",
        ['PriestSilence'] = "no",
        ['RogueBlind'] = "no",
        ['RogueGarrote'] = "no",
        ['Roguekick'] = "no",
        ['RogueSap'] = "no",
        ['ShamanHex'] = "no",
        ['ShamanWindShear'] = "no",
        ['WarlockMesmerize'] = "no",
        ['WarlockSeduction'] = "no",
        ['WarriorDragonRoar'] = 'no',
        ['WarriorPummel'] = "no",
        ['WarriorShockwave'] = "no",
        ['WarriorStormBolt'] = "no",
        ['WarriorStormBoltOffHand'] = "no",
    };
end

function SayKarmaExtraSetTabPvp()
    if UnitAffectingCombat("player") then
        print("SayKarma: Error ! You are in Combat");
        return
    else
        SetBinding("TAB", "TARGETNEARESTENEMYPLAYER");
        SetBinding("SHIFT-TAB", "TARGETNEARESTENEMY");
        SayKarmaPrefs['SayKarmaTabMode'] = "pvp";
        print("SayKarma: Now the Tab key is for pvp mode. Use \"Tab\" for target the nearest enemy player and \"Shift+Tab\" for target the nearest enemy");
    end
end

function SayKarmaExtraSetTabPve()
    if UnitAffectingCombat("player") then
        print("SayKarma: Error ! You are in Combat");
        return
    else
        SetBinding("TAB", "TARGETNEARESTENEMY");
        SetBinding("SHIFT-TAB", "TARGETNEARESTENEMYPLAYER");
        SayKarmaPrefs['SayKarmaTabMode'] = "pve";
        print("SayKarma: Now the Tab key is for pve mode. Use \"Tab\" for target the nearest enemy and \"Shift+Tab\" for target the nearest enemy player");
    end
end

SayKarmaCommand:SetScript("OnEvent", SayKarmaCommand.OnEvent);
